@@ -31,7 +31,7 @@ import subprocess
 import sys
 import zipfile
 
-__version__ = "0.22.0"
+__version__ = "0.23.1"
 
 is_windows = os.name == "nt"
 
@@ -166,7 +166,6 @@ library."""
         "c_header": False,
         "include_source": False,
         "has_source": True,
-        "both_analyzers": False,
     }
     d["uc_name"] = d["name"].upper().replace("-", "_")
     if d["type_id"] != "e":
@@ -185,8 +184,6 @@ library."""
         d["include_source"] = True
     if d["type_id"] == "h":
         d["has_source"] = False
-    if d["use_clang_tidy"] and d["use_cppcheck"]:
-        d["both_analyzers"] = True
     d["c_header"] = d["c"] and d["type_id"] == "h"
     return d
 
@@ -201,15 +198,20 @@ def write_file(path, d, overwrite, zip_path):
 
     def replacer(match):
         query = match.group(1)
+        expected = True
+        if query.endswith("_not"):
+            query = query[:-4]
+            expected = False
         if query == "type":
             mapping = {"exe": "e", "header": "h", "shared": "s"}
-            if mapping[match.group(2)] == d["type_id"]:
+            actual = mapping[match.group(2)] == d["type_id"]
+            if actual == expected:
                 return match.group(3)
-        elif query == "if" and d[match.group(2)] is True:
+        elif query == "if" and d[match.group(2)] == expected:
             return match.group(3)
         return ""
 
-    regex = re.compile("{(type|if) ([^}]+)}(.+?){end}", re.DOTALL)
+    regex = re.compile("{((?:type|if)(?:_not)?) ([^}]+)}(.+?){end}", re.DOTALL)
     contents = regex.sub(replacer, zip_path.read_text(encoding="UTF-8"))
     with open(path, "w", encoding="UTF-8", newline="\n") as f:
         f.write(contents % d)
